diff --git a/core/lib/Drupal/Core/Path/AliasStorageController.php b/core/lib/Drupal/Core/Path/AliasStorageController.php
new file mode 100644
index 0000000..f032049
--- /dev/null
+++ b/core/lib/Drupal/Core/Path/AliasStorageController.php
@@ -0,0 +1,249 @@
+<?php
+
+/**
+ * @file
+ * Contains Drupal\Core\Path\Path.
+ */
+
+namespace Drupal\Core\Path;
+
+use Drupal\Core\Database\Connection;
+use Drupal\Core\Extension\ModuleHandlerInterface;
+use Drupal\Core\Language\Language;
+
+/**
+ * Defines a class for CRUD operations on path aliases.
+ */
+class AliasStorageController {
+
+  /**
+   * The database connection.
+   *
+   * @var \Drupal\Core\Database\Connection
+   */
+  protected $connection;
+
+  /**
+   * The module handler.
+   *
+   * @var \Drupal\Core\Extension\ModuleHandlerInterface
+   */
+  protected $moduleHandler;
+
+  /**
+   * Constructs a Path CRUD object.
+   *
+   * @param \Drupal\Core\Database\Connection $connection
+   *   A database connection for reading and writing path aliases.
+   *
+   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
+   *   The module handler.
+   */
+  public function __construct(Connection $connection, ModuleHandlerInterface $module_handler) {
+    $this->connection = $connection;
+    $this->moduleHandler = $module_handler;
+  }
+
+  /**
+   * Saves a path alias to the database.
+   *
+   * @param string $source
+   *   The internal system path.
+   *
+   * @param string $alias
+   *   The URL alias.
+   *
+   * @param string $langcode
+   *   The language code of the alias.
+   *
+   * @param int $pid
+   *   Unique path alias identifier.
+   *
+   * @return
+   *   FALSE if the path could not be saved or an associative array containing
+   *   the following keys:
+   *   - source: The internal system path.
+   *   - alias: The URL alias.
+   *   - pid: Unique path alias identifier.
+   *   - langcode: The language code of the alias.
+   */
+  public function save($source, $alias, $langcode = Language::LANGCODE_NOT_SPECIFIED, $pid = NULL) {
+
+    $fields = array(
+      'source' => $source,
+      'alias' => $alias,
+      'langcode' => $langcode,
+    );
+
+    // Insert or update the alias.
+    if (empty($pid)) {
+      $query = $this->connection->insert('url_alias')
+        ->fields($fields);
+      $pid = $query->execute();
+      $fields['pid'] = $pid;
+      $operation = 'insert';
+    }
+    else {
+      $fields['pid'] = $pid;
+      $query = $this->connection->update('url_alias')
+        ->fields($fields)
+        ->condition('pid', $pid);
+      $pid = $query->execute();
+      $operation = 'update';
+    }
+    if ($pid) {
+      // @todo Switch to using an event for this instead of a hook.
+      $this->moduleHandler->invokeAll('path_' . $operation, array($fields));
+      return $fields;
+    }
+    return FALSE;
+  }
+
+  /**
+   * Fetches a specific URL alias from the database.
+   *
+   * @param $conditions
+   *   An array of query conditions.
+   *
+   * @return
+   *   FALSE if no alias was found or an associative array containing the
+   *   following keys:
+   *   - source: The internal system path.
+   *   - alias: The URL alias.
+   *   - pid: Unique path alias identifier.
+   *   - langcode: The language code of the alias.
+   */
+  public function load($conditions) {
+    $select = $this->connection->select('url_alias');
+    foreach ($conditions as $field => $value) {
+      $select->condition($field, $value);
+    }
+    return $select
+      ->fields('url_alias')
+      ->execute()
+      ->fetchAssoc();
+  }
+
+  /**
+   * Deletes a URL alias.
+   *
+   * @param array $conditions
+   *   An array of criteria.
+   */
+  public function delete($conditions) {
+    $path = $this->load($conditions);
+    $query = $this->connection->delete('url_alias');
+    foreach ($conditions as $field => $value) {
+      $query->condition($field, $value);
+    }
+    $deleted = $query->execute();
+    // @todo Switch to using an event for this instead of a hook.
+    $this->moduleHandler->invokeAll('path_delete', array($path));
+    return $deleted;
+  }
+
+  /**
+   * Preloads path alias information for a given list of source paths.
+   *
+   * @param $path
+   *   The path to investigate for corresponding aliases.
+   * @param $langcode
+   *   Language code to search the path with. If there's no path defined for
+   *   that language it will search paths without language.
+   * @return array
+   *   Source (keys) to alias (values) mapping.
+   */
+  public function preloadPathAlias($preloaded, $langcode) {
+    $args = array(
+      ':system' => $preloaded,
+      ':langcode' => $langcode,
+      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
+    );
+    // Always get the language-specific alias before the language-neutral one.
+    // For example 'de' is less than 'und' so the order needs to be ASC, while
+    // 'xx-lolspeak' is more than 'und' so the order needs to be DESC. We also
+    // order by pid ASC so that fetchAllKeyed() returns the most recently
+    // created alias for each source. Subsequent queries using fetchField() must
+    // use pid DESC to have the same effect. For performance reasons, the query
+    // builder is not used here.
+    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
+      // Prevent PDO from complaining about a token the query doesn't use.
+      unset($args[':langcode']);
+      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode = :langcode_undetermined ORDER BY pid ASC', $args);
+    }
+    elseif ($langcode < Language::LANGCODE_NOT_SPECIFIED) {
+      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid ASC', $args);
+    }
+    else {
+      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid ASC', $args);
+    }
+
+    return $result->fetchAllKeyed();
+  }
+
+  /**
+   * Returns an alias of Drupal system URL.
+   *
+   * @param string $path
+   *   The path to investigate for corresponding path aliases.
+   * @param string $langcode
+   *   Language code to search the path with. If there's no path defined for
+   *   that language it will search paths without language.
+   *
+   * @return string|bool
+   *   A path alias, or FALSE if no path was found.
+   */
+  public function lookupPathAlias($path, $langcode) {
+    $args = array(
+      ':source' => $path,
+      ':langcode' => $langcode,
+      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
+    );
+    // See the queries above.
+    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
+      unset($args[':langcode']);
+      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode = :langcode_undetermined ORDER BY pid DESC", $args)->fetchField();
+    }
+    elseif ($langcode > Language::LANGCODE_NOT_SPECIFIED) {
+      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid DESC", $args)->fetchField();
+    }
+    else {
+      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid DESC", $args)->fetchField();
+    }
+
+    return $alias;
+  }
+
+  /**
+   * Returns Drupal system URL of an alias.
+   *
+   * @param string $path
+   *   The path to investigate for corresponding system URLs.
+   * @param string $langcode
+   *   Language code to search the path with. If there's no path defined for
+   *   that language it will search paths without language.
+   *
+   * @return string|bool
+   *   A Drupal system path, or FALSE if no path was found.
+   */
+  public function lookupPathSource($path, $langcode) {
+    $args = array(
+      ':alias' => $path,
+      ':langcode' => $langcode,
+      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
+    );
+    // See the queries above.
+    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
+      unset($args[':langcode']);
+      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode = :langcode_undetermined ORDER BY pid DESC", $args);
+    }
+    elseif ($langcode > Language::LANGCODE_NOT_SPECIFIED) {
+      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid DESC", $args);
+    }
+    else {
+      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid DESC", $args);
+    }
+
+    return $result->fetchField();
+  }
+}
diff --git a/core/lib/Drupal/Core/Path/Path.php b/core/lib/Drupal/Core/Path/Path.php
deleted file mode 100644
index 6802030..0000000
--- a/core/lib/Drupal/Core/Path/Path.php
+++ /dev/null
@@ -1,249 +0,0 @@
-<?php
-
-/**
- * @file
- * Contains Drupal\Core\Path\Path.
- */
-
-namespace Drupal\Core\Path;
-
-use Drupal\Core\Database\Connection;
-use Drupal\Core\Extension\ModuleHandlerInterface;
-use Drupal\Core\Language\Language;
-
-/**
- * Defines a class for CRUD operations on path aliases.
- */
-class Path {
-
-  /**
-   * The database connection.
-   *
-   * @var \Drupal\Core\Database\Connection
-   */
-  protected $connection;
-
-  /**
-   * The module handler.
-   *
-   * @var \Drupal\Core\Extension\ModuleHandlerInterface
-   */
-  protected $moduleHandler;
-
-  /**
-   * Constructs a Path CRUD object.
-   *
-   * @param \Drupal\Core\Database\Connection $connection
-   *   A database connection for reading and writing path aliases.
-   *
-   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
-   *   The module handler.
-   */
-  public function __construct(Connection $connection, ModuleHandlerInterface $module_handler) {
-    $this->connection = $connection;
-    $this->moduleHandler = $module_handler;
-  }
-
-  /**
-   * Saves a path alias to the database.
-   *
-   * @param string $source
-   *   The internal system path.
-   *
-   * @param string $alias
-   *   The URL alias.
-   *
-   * @param string $langcode
-   *   The language code of the alias.
-   *
-   * @param int $pid
-   *   Unique path alias identifier.
-   *
-   * @return
-   *   FALSE if the path could not be saved or an associative array containing
-   *   the following keys:
-   *   - source: The internal system path.
-   *   - alias: The URL alias.
-   *   - pid: Unique path alias identifier.
-   *   - langcode: The language code of the alias.
-   */
-  public function save($source, $alias, $langcode = Language::LANGCODE_NOT_SPECIFIED, $pid = NULL) {
-
-    $fields = array(
-      'source' => $source,
-      'alias' => $alias,
-      'langcode' => $langcode,
-    );
-
-    // Insert or update the alias.
-    if (empty($pid)) {
-      $query = $this->connection->insert('url_alias')
-        ->fields($fields);
-      $pid = $query->execute();
-      $fields['pid'] = $pid;
-      $operation = 'insert';
-    }
-    else {
-      $fields['pid'] = $pid;
-      $query = $this->connection->update('url_alias')
-        ->fields($fields)
-        ->condition('pid', $pid);
-      $pid = $query->execute();
-      $operation = 'update';
-    }
-    if ($pid) {
-      // @todo Switch to using an event for this instead of a hook.
-      $this->moduleHandler->invokeAll('path_' . $operation, array($fields));
-      return $fields;
-    }
-    return FALSE;
-  }
-
-  /**
-   * Fetches a specific URL alias from the database.
-   *
-   * @param $conditions
-   *   An array of query conditions.
-   *
-   * @return
-   *   FALSE if no alias was found or an associative array containing the
-   *   following keys:
-   *   - source: The internal system path.
-   *   - alias: The URL alias.
-   *   - pid: Unique path alias identifier.
-   *   - langcode: The language code of the alias.
-   */
-  public function load($conditions) {
-    $select = $this->connection->select('url_alias');
-    foreach ($conditions as $field => $value) {
-      $select->condition($field, $value);
-    }
-    return $select
-      ->fields('url_alias')
-      ->execute()
-      ->fetchAssoc();
-  }
-
-  /**
-   * Deletes a URL alias.
-   *
-   * @param array $conditions
-   *   An array of criteria.
-   */
-  public function delete($conditions) {
-    $path = $this->load($conditions);
-    $query = $this->connection->delete('url_alias');
-    foreach ($conditions as $field => $value) {
-      $query->condition($field, $value);
-    }
-    $deleted = $query->execute();
-    // @todo Switch to using an event for this instead of a hook.
-    $this->moduleHandler->invokeAll('path_delete', array($path));
-    return $deleted;
-  }
-
-  /**
-   * Preloads path alias information for a given list of source paths.
-   *
-   * @param $path
-   *   The path to investigate for corresponding aliases.
-   * @param $langcode
-   *   Language code to search the path with. If there's no path defined for
-   *   that language it will search paths without language.
-   * @return array
-   *   Source (keys) to alias (values) mapping.
-   */
-  public function preloadPathAlias($preloaded, $langcode) {
-    $args = array(
-      ':system' => $preloaded,
-      ':langcode' => $langcode,
-      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
-    );
-    // Always get the language-specific alias before the language-neutral one.
-    // For example 'de' is less than 'und' so the order needs to be ASC, while
-    // 'xx-lolspeak' is more than 'und' so the order needs to be DESC. We also
-    // order by pid ASC so that fetchAllKeyed() returns the most recently
-    // created alias for each source. Subsequent queries using fetchField() must
-    // use pid DESC to have the same effect. For performance reasons, the query
-    // builder is not used here.
-    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
-      // Prevent PDO from complaining about a token the query doesn't use.
-      unset($args[':langcode']);
-      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode = :langcode_undetermined ORDER BY pid ASC', $args);
-    }
-    elseif ($langcode < Language::LANGCODE_NOT_SPECIFIED) {
-      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid ASC', $args);
-    }
-    else {
-      $result = $this->connection->query('SELECT source, alias FROM {url_alias} WHERE source IN (:system) AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid ASC', $args);
-    }
-
-    return $result->fetchAllKeyed();
-  }
-
-  /**
-   * Returns an alias of Drupal system URL.
-   *
-   * @param string $path
-   *   The path to investigate for corresponding path aliases.
-   * @param string $langcode
-   *   Language code to search the path with. If there's no path defined for
-   *   that language it will search paths without language.
-   *
-   * @return string|bool
-   *   A path alias, or FALSE if no path was found.
-   */
-  public function lookupPathAlias($path, $langcode) {
-    $args = array(
-      ':source' => $path,
-      ':langcode' => $langcode,
-      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
-    );
-    // See the queries above.
-    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
-      unset($args[':langcode']);
-      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode = :langcode_undetermined ORDER BY pid DESC", $args)->fetchField();
-    }
-    elseif ($langcode > Language::LANGCODE_NOT_SPECIFIED) {
-      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid DESC", $args)->fetchField();
-    }
-    else {
-      $alias = $this->connection->query("SELECT alias FROM {url_alias} WHERE source = :source AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid DESC", $args)->fetchField();
-    }
-
-    return $alias;
-  }
-
-  /**
-   * Returns Drupal system URL of an alias.
-   *
-   * @param string $path
-   *   The path to investigate for corresponding system URLs.
-   * @param string $langcode
-   *   Language code to search the path with. If there's no path defined for
-   *   that language it will search paths without language.
-   *
-   * @return string|bool
-   *   A Drupal system path, or FALSE if no path was found.
-   */
-  public function lookupPathSource($path, $langcode) {
-    $args = array(
-      ':alias' => $path,
-      ':langcode' => $langcode,
-      ':langcode_undetermined' => Language::LANGCODE_NOT_SPECIFIED,
-    );
-    // See the queries above.
-    if ($langcode == Language::LANGCODE_NOT_SPECIFIED) {
-      unset($args[':langcode']);
-      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode = :langcode_undetermined ORDER BY pid DESC", $args);
-    }
-    elseif ($langcode > Language::LANGCODE_NOT_SPECIFIED) {
-      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode DESC, pid DESC", $args);
-    }
-    else {
-      $result = $this->connection->query("SELECT source FROM {url_alias} WHERE alias = :alias AND langcode IN (:langcode, :langcode_undetermined) ORDER BY langcode ASC, pid DESC", $args);
-    }
-
-    return $result->fetchField();
-  }
-}
diff --git a/core/modules/system/lib/Drupal/system/Tests/Path/AliasTest.php b/core/modules/system/lib/Drupal/system/Tests/Path/AliasTest.php
index 5f5d368..b0c33a8 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Path/AliasTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Path/AliasTest.php
@@ -8,7 +8,7 @@
 namespace Drupal\system\Tests\Path;
 
 use Drupal\Core\Cache\MemoryCounterBackend;
-use Drupal\Core\Path\Path;
+use Drupal\Core\Path\AliasStorageController;
 use Drupal\Core\Database\Database;
 use Drupal\Core\Path\AliasManager;
 use Drupal\Core\Path\AliasWhitelist;
@@ -32,13 +32,13 @@ function testCRUD() {
     $this->fixtures->createTables($connection);
 
     //Create Path object.
-    $path = new Path($connection, $this->container->get('module_handler'));
+    $aliasStorageController = new AliasStorageController($connection, $this->container->get('module_handler'));
 
     $aliases = $this->fixtures->sampleUrlAliases();
 
     //Create a few aliases
     foreach ($aliases as $idx => $alias) {
-      $path->save($alias['source'], $alias['alias'], $alias['langcode']);
+      $aliasStorageController->save($alias['source'], $alias['alias'], $alias['langcode']);
 
       $result = $connection->query('SELECT * FROM {url_alias} WHERE source = :source AND alias= :alias AND langcode = :langcode', array(':source' => $alias['source'], ':alias' => $alias['alias'], ':langcode' => $alias['langcode']));
       $rows = $result->fetchAll();
@@ -52,13 +52,13 @@ function testCRUD() {
     //Load a few aliases
     foreach ($aliases as $alias) {
       $pid = $alias['pid'];
-      $loadedAlias = $path->load(array('pid' => $pid));
+      $loadedAlias = $aliasStorageController->load(array('pid' => $pid));
       $this->assertEqual($loadedAlias, $alias, format_string('Loaded the expected path with pid %pid.', array('%pid' => $pid)));
     }
 
     //Update a few aliases
     foreach ($aliases as $alias) {
-      $path->save($alias['source'], $alias['alias'] . '_updated', $alias['langcode'], $alias['pid']);
+      $aliasStorageController->save($alias['source'], $alias['alias'] . '_updated', $alias['langcode'], $alias['pid']);
 
       $result = $connection->query('SELECT pid FROM {url_alias} WHERE source = :source AND alias= :alias AND langcode = :langcode', array(':source' => $alias['source'], ':alias' => $alias['alias'] . '_updated', ':langcode' => $alias['langcode']));
       $pid = $result->fetchField();
@@ -69,7 +69,7 @@ function testCRUD() {
     //Delete a few aliases
     foreach ($aliases as $alias) {
       $pid = $alias['pid'];
-      $path->delete(array('pid' => $pid));
+      $aliasStorageController->delete(array('pid' => $pid));
 
       $result = $connection->query('SELECT * FROM {url_alias} WHERE pid = :pid', array(':pid' => $pid));
       $rows = $result->fetchAll();
@@ -85,7 +85,7 @@ function testLookupPath() {
 
     //Create AliasManager and Path object.
     $aliasManager = $this->container->get('path.alias_manager.cached');
-    $pathObject = new Path($connection, $this->container->get('module_handler'));
+    $aliasStorageController = new AliasStorageController($connection, $this->container->get('module_handler'));
 
     // Test the situation where the source is the same for multiple aliases.
     // Start with a language-neutral alias, which we will override.
@@ -94,7 +94,7 @@ function testLookupPath() {
       'alias' => 'foo',
     );
 
-    $pathObject->save($path['source'], $path['alias']);
+    $aliasStorageController->save($path['source'], $path['alias']);
     $this->assertEqual($aliasManager->getPathAlias($path['source']), $path['alias'], 'Basic alias lookup works.');
     $this->assertEqual($aliasManager->getSystemPath($path['alias']), $path['source'], 'Basic source lookup works.');
 
@@ -104,7 +104,7 @@ function testLookupPath() {
       'alias' => "users/Dries",
       'langcode' => 'en',
     );
-    $pathObject->save($path['source'], $path['alias'], $path['langcode']);
+    $aliasStorageController->save($path['source'], $path['alias'], $path['langcode']);
     // Hook that clears cache is not executed with unit tests.
     \Drupal::service('path.alias_manager.cached')->cacheClear();
     $this->assertEqual($aliasManager->getPathAlias($path['source']), $path['alias'], 'English alias overrides language-neutral alias.');
@@ -115,7 +115,7 @@ function testLookupPath() {
       'source' => "user/1",
       'alias' => 'bar',
     );
-    $pathObject->save($path['source'], $path['alias']);
+    $aliasStorageController->save($path['source'], $path['alias']);
     $this->assertEqual($aliasManager->getPathAlias($path['source']), "users/Dries", 'English alias still returned after entering a language-neutral alias.');
 
     // Create a language-specific (xx-lolspeak) alias for the same path.
@@ -124,7 +124,7 @@ function testLookupPath() {
       'alias' => 'LOL',
       'langcode' => 'xx-lolspeak',
     );
-    $pathObject->save($path['source'], $path['alias'], $path['langcode']);
+    $aliasStorageController->save($path['source'], $path['alias'], $path['langcode']);
     $this->assertEqual($aliasManager->getPathAlias($path['source']), "users/Dries", 'English alias still returned after entering a LOLspeak alias.');
     // The LOLspeak alias should be returned if we really want LOLspeak.
     $this->assertEqual($aliasManager->getPathAlias($path['source'], 'xx-lolspeak'), 'LOL', 'LOLspeak alias returned if we specify xx-lolspeak to the alias manager.');
@@ -136,7 +136,7 @@ function testLookupPath() {
       'alias' => 'users/my-new-path',
       'langcode' => 'en',
     );
-    $pathObject->save($path['source'], $path['alias'], $path['langcode']);
+    $aliasStorageController->save($path['source'], $path['alias'], $path['langcode']);
     // Hook that clears cache is not executed with unit tests.
     $aliasManager->cacheClear();
     $this->assertEqual($aliasManager->getPathAlias($path['source']), $path['alias'], 'Recently created English alias returned.');
@@ -144,14 +144,14 @@ function testLookupPath() {
 
     // Remove the English aliases, which should cause a fallback to the most
     // recently created language-neutral alias, 'bar'.
-    $pathObject->delete(array('langcode' => 'en'));
+    $aliasStorageController->delete(array('langcode' => 'en'));
     // Hook that clears cache is not executed with unit tests.
     $aliasManager->cacheClear();
     $this->assertEqual($aliasManager->getPathAlias($path['source']), 'bar', 'Path lookup falls back to recently created language-neutral alias.');
 
     // Test the situation where the alias and language are the same, but
     // the source differs. The newer alias record should be returned.
-    $pathObject->save('user/2', 'bar');
+    $aliasStorageController->save('user/2', 'bar');
     // Hook that clears cache is not executed with unit tests.
     $aliasManager->cacheClear();
     $this->assertEqual($aliasManager->getSystemPath('bar'), 'user/2', 'Newer alias record is returned when comparing two Language::LANGCODE_NOT_SPECIFIED paths with the same alias.');
@@ -169,8 +169,8 @@ function testWhitelist() {
 
     // Create AliasManager and Path object.
     $whitelist = new AliasWhitelist('path_alias_whitelist', $memoryCounterBackend, $this->container->get('lock'), $this->container->get('state'), $connection);
-    $path = new Path($connection, $this->container->get('module_handler'));
-    $aliasManager = new AliasManager($path, $whitelist, $this->container->get('language_manager'));
+    $aliasStorageController = new AliasStorageController($connection, $this->container->get('module_handler'));
+    $aliasManager = new AliasManager($aliasStorageController, $whitelist, $this->container->get('language_manager'));
 
     // No alias for user and admin yet, so should be NULL.
     $this->assertNull($whitelist->get('user'));
@@ -181,21 +181,21 @@ function testWhitelist() {
     $this->assertNull($whitelist->get($this->randomName()));
 
     // Add an alias for user/1, user should get whitelisted now.
-    $path->save('user/1', $this->randomName());
+    $aliasStorageController->save('user/1', $this->randomName());
     $aliasManager->cacheClear();
     $this->assertTrue($whitelist->get('user'));
     $this->assertNull($whitelist->get('admin'));
     $this->assertNull($whitelist->get($this->randomName()));
 
     // Add an alias for admin, both should get whitelisted now.
-    $path->save('admin/something', $this->randomName());
+    $aliasStorageController->save('admin/something', $this->randomName());
     $aliasManager->cacheClear();
     $this->assertTrue($whitelist->get('user'));
     $this->assertTrue($whitelist->get('admin'));
     $this->assertNull($whitelist->get($this->randomName()));
 
     // Remove the user alias again, whitelist entry should be removed.
-    $path->delete(array('source' => 'user/1'));
+    $aliasStorageController->delete(array('source' => 'user/1'));
     $aliasManager->cacheClear();
     $this->assertNull($whitelist->get('user'));
     $this->assertTrue($whitelist->get('admin'));

diff --git a/core/lib/Drupal/Core/Path/AliasManager.php b/core/lib/Drupal/Core/Path/AliasManager.php
index da3555b..ac025ef 100644
--- a/core/lib/Drupal/Core/Path/AliasManager.php
+++ b/core/lib/Drupal/Core/Path/AliasManager.php
@@ -13,11 +13,11 @@
 class AliasManager implements AliasManagerInterface {
 
   /**
-   * The Path CRUD service.
+   * The alias storage controller service.
    *
-   * @var \Drupal\Core\Path\Path
+   * @var \Drupal\Core\Path\AliasStorageController
    */
-  protected $path;
+  protected $storageController;
 
   /**
    * Language manager for retrieving the default langcode when none is specified.
@@ -74,15 +74,15 @@ class AliasManager implements AliasManagerInterface {
   /**
    * Constructs an AliasManager.
    *
    * @param \Drupal\Core\Path\Path $path
    *   The Path CRUD service.
    * @param \Drupal\Core\Path\AliasWhitelistInterface $whitelist
    *   The whitelist implementation to use.
    * @param \Drupal\Core\Language\LanguageManager $language_manager
    *   The language manager.
    */
-  public function __construct(Path $path, AliasWhitelistInterface $whitelist, LanguageManager $language_manager) {
-    $this->path = $path;
+  public function __construct(AliasStorageController $storage_controller, AliasWhitelistInterface $whitelist, LanguageManager $language_manager) {
+    $this->storageController = $storage_controller;
     $this->languageManager = $language_manager;
     $this->whitelist = $whitelist;
   }
@@ -180,7 +180,7 @@ protected function lookupPathAlias($path, $langcode) {
       // Load system paths from cache.
       if (!empty($this->preloadedPathLookups)) {
         // Now fetch the aliases corresponding to these system paths.
-        $this->lookupMap[$langcode] = $this->path->preloadPathAlias($this->preloadedPathLookups, $langcode);
+        $this->lookupMap[$langcode] = $this->storageController->preloadPathAlias($this->preloadedPathLookups, $langcode);
         // Keep a record of paths with no alias to avoid querying twice.
         $this->noAliases[$langcode] = array_flip(array_diff_key($this->preloadedPathLookups, array_keys($this->lookupMap[$langcode])));
       }
@@ -197,7 +197,7 @@ protected function lookupPathAlias($path, $langcode) {
     }
     // For system paths which were not cached, query aliases individually.
     elseif (!isset($this->noAliases[$langcode][$path])) {
-      $this->lookupMap[$langcode][$path] = $this->path->lookupPathAlias($path, $langcode);
+      $this->lookupMap[$langcode][$path] = $this->storageController->lookupPathAlias($path, $langcode);
       return $this->lookupMap[$langcode][$path];
     }
     return FALSE;
@@ -222,7 +222,7 @@ protected function lookupPathSource($path, $langcode) {
       // Look for the value $path within the cached $map
       $source = isset($this->lookupMap[$langcode]) ? array_search($path, $this->lookupMap[$langcode]) : FALSE;
       if (!$source) {
-        if ($source = $this->path->lookupPathSource($path, $langcode)) {
+        if ($source = $this->storageController->lookupPathSource($path, $langcode)) {
           $this->lookupMap[$langcode][$source] = $path;
         }
         else {
@@ -74,15 +74,15 @@ class AliasManager implements AliasManagerInterface {
    * Constructs an AliasManager.
    *
-   * @param \Drupal\Core\Path\Path $path
-   *   The Path CRUD service.
+   * @param \Drupal\Core\Path\AliasStorageController $storage_controller
+   *   The alias storage controller service.
    * @param \Drupal\Core\Path\AliasWhitelistInterface $whitelist
    *   The whitelist implementation to use.
diff --git a/core/modules/path/lib/Drupal/path/Form/DeleteForm.php b/core/modules/path/lib/Drupal/path/Form/DeleteForm.php
index 9c84de8..3ae06da 100644
--- a/core/modules/path/lib/Drupal/path/Form/DeleteForm.php
+++ b/core/modules/path/lib/Drupal/path/Form/DeleteForm.php
@@ -8,7 +8,7 @@
 namespace Drupal\path\Form;
 
 use Drupal\Core\Form\ConfirmFormBase;
-use Drupal\Core\Path\Path;
+use Drupal\Core\Path\AliasStorageController;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
@@ -17,11 +17,11 @@
 class DeleteForm extends ConfirmFormBase {
 
   /**
-   * The path crud service.
+   * The alias storage controller service.
    *
-   * @var Path $path
+   * @var AliasStorageController $path
    */
-  protected $path;
+  protected $aliasStorageController;
 
   /**
    * The path alias being deleted.
@@ -33,11 +33,11 @@ class DeleteForm extends ConfirmFormBase {
   /**
    * Constructs a \Drupal\Core\Path\Path object.
    *
    * @param \Drupal\Core\Path\Path $path
    *   The path crud service.
    */
-  public function __construct(Path $path) {
-    $this->path = $path;
+  public function __construct(AliasStorageController $alias_storage_controller) {
+    $this->aliasStorageController = $alias_storage_controller;
   }
 
   /**
@@ -73,7 +73,7 @@ public function getCancelRoute() {
    * Overrides \Drupal\Core\Form\ConfirmFormBase::buildForm().
    */
   public function buildForm(array $form, array &$form_state, $pid = NULL) {
-    $this->pathAlias = $this->path->load(array('pid' => $pid));
+    $this->pathAlias = $this->aliasStorageController->load(array('pid' => $pid));
 
     $form = parent::buildForm($form, $form_state);
 
@@ -86,7 +86,7 @@ public function buildForm(array $form, array &$form_state, $pid = NULL) {
    * Implements \Drupal\Core\Form\FormInterface::submitForm().
    */
   public function submitForm(array &$form, array &$form_state) {
-    $this->path->delete(array('pid' => $this->pathAlias['pid']));
+    $this->aliasStorageController->delete(array('pid' => $this->pathAlias['pid']));
 
     $form_state['redirect'] = 'admin/config/search/path';
   }
@@ -33,11 +33,11 @@ class DeleteForm extends ConfirmFormBase {
    * Constructs a \Drupal\Core\Path\Path object.
    *
-   * @param \Drupal\Core\Path\Path $path
-   *   The path crud service.
+   * @param \Drupal\Core\Path\AliasStorageController $alias_storage_controller
+   *   The alias storage controller service.
    */